@@ -29,7 +29,7 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  * ---------------------------------------------------------------------- 
  * 
- * $Id: pde.cpp,v 1.1 2007/06/14 15:27:45 gkrawczyk Exp $
+ * $Id: pde.cpp,v 1.3 2008/09/04 12:46:49 julians37 Exp $
  */
 
 #if HAVE_CONFIG_H
@@ -77,7 +77,7 @@ inline float min( float a, float b )
 
 //!! TODO: for debugging purposes
 // #define PFSEOL "\x0a"
-// static void dumpPFS( const char *fileName, const pfs::Array2D *data, const char *channelName )
+// static void dumpPFS( const char *fileName, const pfstmo::Array2D *data, const char *channelName )
 // {
 //   FILE *fh = fopen( fileName, "wb" );
 //   assert( fh != NULL );
@@ -100,7 +100,7 @@ inline float min( float a, float b )
 // Full Multigrid Algorithm for solving partial differential equations
 //////////////////////////////////////////////////////////////////////
 
-void restrict( const pfs::Array2D *in, pfs::Array2D *out )
+void restrict( const pfstmo::Array2D *in, pfstmo::Array2D *out )
 {
   const float inRows = in->getRows();
   const float inCols = in->getCols();
@@ -131,7 +131,7 @@ void restrict( const pfs::Array2D *in, pfs::Array2D *out )
 }
 
 // from_level>to_level, from_size>to_size
-// void restrict( pfs::Array2D *F, pfs::Array2D *T )
+// void restrict( pfstmo::Array2D *F, pfstmo::Array2D *T )
 // {
 // //   DEBUG_STR << "restrict" << endl;
   
@@ -163,7 +163,7 @@ void restrict( const pfs::Array2D *in, pfs::Array2D *out )
 // }
 
 
-void prolongate( const pfs::Array2D *in, pfs::Array2D *out )
+void prolongate( const pfstmo::Array2D *in, pfstmo::Array2D *out )
 {
   float dx = (float)in->getCols() / (float)out->getCols();
   float dy = (float)in->getRows() / (float)out->getRows();
@@ -207,7 +207,7 @@ void prolongate( const pfs::Array2D *in, pfs::Array2D *out )
 }
 
 // to_level<from_level, from_size<to_size
-void prolongate_old( pfs::Array2D *F, pfs::Array2D *T )
+void prolongate_old( pfstmo::Array2D *F, pfstmo::Array2D *T )
 {
 //   DEBUG_STR << "prolongate" << endl;
 
@@ -268,7 +268,7 @@ void prolongate_old( pfs::Array2D *F, pfs::Array2D *T )
     }
 }
 
-void exact_sollution( pfs::Array2D *F, pfs::Array2D *U )
+void exact_sollution( pfstmo::Array2D *F, pfstmo::Array2D *U )
 {
 //   DEBUG_STR << "exact sollution" << endl;
 
@@ -311,7 +311,7 @@ inline int idx( int r, int c )
 }
 
 // smooth u using f at level
-void smooth( pfs::Array2DImpl *U, pfs::Array2DImpl *F )
+void smooth( pfstmo::Array2D *U, pfstmo::Array2D *F )
 {
 //   DEBUG_STR << "smooth" << endl;
   
@@ -360,7 +360,7 @@ void smooth( pfs::Array2DImpl *U, pfs::Array2DImpl *F )
 //   }
 }
 
-void calculate_defect( pfs::Array2D *D, pfs::Array2D *U, pfs::Array2D *F )
+void calculate_defect( pfstmo::Array2D *D, pfstmo::Array2D *U, pfstmo::Array2D *F )
 {
 //   DEBUG_STR << "calculate defect" << endl;
 
@@ -386,7 +386,7 @@ void calculate_defect( pfs::Array2D *D, pfs::Array2D *U, pfs::Array2D *F )
   
 }
 
-void add_correction( pfs::Array2D *U, pfs::Array2D *C )
+void add_correction( pfstmo::Array2D *U, pfstmo::Array2D *C )
 {
 //   DEBUG_STR << "add_correction" << endl;
 
@@ -398,7 +398,7 @@ void add_correction( pfs::Array2D *U, pfs::Array2D *C )
 }
 
 
-void solve_pde_multigrid( pfs::Array2D *F, pfs::Array2D *U )
+void solve_pde_multigrid( pfstmo::Array2D *F, pfstmo::Array2D *U )
 {
   int xmax = F->getCols();
   int ymax = F->getRows();
@@ -420,17 +420,17 @@ void solve_pde_multigrid( pfs::Array2D *F, pfs::Array2D *U )
   }
 
   // given function f restricted on levels
-  pfs::Array2D** RHS = new pfs::Array2D*[levels+1];
+  pfstmo::Array2D** RHS = new pfstmo::Array2D*[levels+1];
 
   // approximate initial sollutions on levels
-  pfs::Array2DImpl** IU = new pfs::Array2DImpl*[levels+1];
+  pfstmo::Array2D** IU = new pfstmo::Array2D*[levels+1];
   // target functions in cycles (approximate sollution error (uh - ~uh) )
-  pfs::Array2DImpl** VF = new pfs::Array2DImpl*[levels+1];
+  pfstmo::Array2D** VF = new pfstmo::Array2D*[levels+1];
 
-  VF[0] = new pfs::Array2DImpl(xmax,ymax);
+  VF[0] = new pfstmo::Array2D(xmax,ymax);
   RHS[0] = F;
-  IU[0] = new pfs::Array2DImpl(xmax,ymax);
-  pfs::copyArray( U, IU[0] );
+  IU[0] = new pfstmo::Array2D(xmax,ymax);
+  pfstmo::copyArray( U, IU[0] );
 
   int sx=xmax;
   int sy=ymax;
@@ -441,9 +441,9 @@ void solve_pde_multigrid( pfs::Array2D *F, pfs::Array2D *U )
     sx=sx/2+MODYF;
     sy=sy/2+MODYF;
     
-    RHS[k+1] = new pfs::Array2DImpl(sx,sy);
-    IU[k+1] = new pfs::Array2DImpl(sx,sy);
-    VF[k+1] = new pfs::Array2DImpl(sx,sy);
+    RHS[k+1] = new pfstmo::Array2D(sx,sy);
+    IU[k+1] = new pfstmo::Array2D(sx,sy);
+    VF[k+1] = new pfstmo::Array2D(sx,sy);
 
     // restrict from level k to level k+1 (coarser-grid)
     restrict( RHS[k], RHS[k+1] );
@@ -484,7 +484,7 @@ void solve_pde_multigrid( pfs::Array2D *F, pfs::Array2D *U )
 
         // 8. calculate defect at level
         //    d[k2] = Lh * ~u[k2] - f[k2]
-        pfs::Array2D* D = new pfs::Array2DImpl(IU[k2]->getCols(), IU[k2]->getRows());
+        pfstmo::Array2D* D = new pfstmo::Array2D(IU[k2]->getCols(), IU[k2]->getRows());
 	calculate_defect( D, IU[k2], VF[k2] );
 
         // 9. restrict deffect as target function for next coarser-grid
@@ -503,7 +503,7 @@ void solve_pde_multigrid( pfs::Array2D *F, pfs::Array2D *U )
       {
         // 12. interpolate correction from last coarser-grid to finer-grid
         //     iu[k2+1] -> cor
-        pfs::Array2D* C = new pfs::Array2DImpl(IU[k2]->getCols(), IU[k2]->getRows());
+        pfstmo::Array2D* C = new pfstmo::Array2D(IU[k2]->getCols(), IU[k2]->getRows());
 	prolongate( IU[k2+1], C );
 
         // 13. add interpolated correction to initial sollution at level k2
@@ -534,7 +534,7 @@ void solve_pde_multigrid( pfs::Array2D *F, pfs::Array2D *U )
 //     dumpPFS( name, VF[k], "Y" );
 //   }  
 
-  pfs::copyArray( IU[0], U );
+  pfstmo::copyArray( IU[0], U );
   
   delete VF[0];
   delete IU[0];
@@ -545,9 +545,9 @@ void solve_pde_multigrid( pfs::Array2D *F, pfs::Array2D *U )
     delete VF[k];
   }
 
-  delete RHS;
-  delete IU;
-  delete VF;
+  delete[] RHS;
+  delete[] IU;
+  delete[] VF;
 
   DEBUG_STR << "FMG: solved\n";
 }
@@ -559,7 +559,7 @@ void solve_pde_multigrid( pfs::Array2D *F, pfs::Array2D *U )
 // SOR - Succesive Overrelaxation Algorithm
 //////////////////////////////////////////////////////////////////////
 
-void solve_pde_sor( pfs::Array2D *F, pfs::Array2D *U, int maxits)
+void solve_pde_sor( pfstmo::Array2D *F, pfstmo::Array2D *U, int maxits)
 {
   DEBUG_STR << "sor" << endl;
 
